@@ -4,8 +4,10 @@ import os
 import shutil
 import sys
 import time
+import warnings
 from pathlib import Path
 
+import numpy as np
 import pandas as pd
 from pyispace.example import save_opts
 from pyispace.trace import trace_build_wrapper, make_summary, _empty_footprint  # noqa
@@ -13,7 +15,7 @@ from pyispace.utils import save_footprint, scriptcsv
 
 from . import integrator, formatter
 from .context import Configuration, Workspace
-from .feature_selection import filtfeat
+from .feature_selection import filtfeat, variance_filter, correlation_filter
 from .metrics import loss_threshold
 from .visualization import Demo, AppClassification
 
@@ -89,21 +91,37 @@ def main(args):
             n_feat_cols = len(df_metadata.filter(regex='^feature_').columns)
             if n_feat_cols > conf.fs.max_n_features:
                 logger.info("Feature selection on")
-                logger.info(f"Chosen method: {conf.fs.method}")
 
                 df_metadata.to_csv(rootdir_path / 'metadata_full.csv')
 
                 df_features = df_metadata.filter(regex='^feature_')
                 df_algo = df_metadata.filter(regex='^algo_')
-                features = df_features.columns.to_list()
+                features = df_features.columns
+                X = df_features.values
+                Y = df_algo.values
 
+                mask = np.ones(X.shape[1], dtype=bool)
+                idx = np.arange(X.shape[1])
+                if conf.fs.var_filter:
+                    logger.info("Applying varicance threshold")
+                    mask = variance_filter(X, threshold=conf.fs.var_threshold)
+                    idx = idx[mask]
+                    logger.info(f"Removed features: {features[~mask].to_list()}")
+                if conf.fs.corr_filter:
+                    logger.info("Applying correlation threshold")
+                    mask2 = correlation_filter(X[:, mask], threshold=conf.fs.corr_threshold)
+                    idx = idx[mask2]
+                    logger.info(f"Removed features: {features[mask][~mask2].to_list()}")
+
+                logger.info(f"Applying main filtering method: {conf.fs.method}")
                 fs_params = {**conf.fs.parameters, **{'standardize': False}}
                 selected = filtfeat(
-                    X=df_features.values,
-                    Y=df_algo.values,
+                    X=X[:, idx],
+                    Y=Y,
                     method=conf.fs.method,
                     max_n_features=conf.fs.max_n_features,
-                    names=features,
+                    names=features[idx].to_list(),
+                    n_jobs=-1,
                     **fs_params
                 )
 
@@ -112,11 +130,12 @@ def main(args):
                                    f"An attempt with a pre-fixed number (10) of features to be selected will be made")
                     fs_params = {**fs_params, **{'n_features_to_select': 10}}
                     selected = filtfeat(
-                        X=df_features.values,
-                        Y=df_algo.values,
+                        X=X[:, idx],
+                        Y=Y,
                         method=conf.fs.method,
                         max_n_features=conf.fs.max_n_features,
-                        names=features,
+                        names=features[idx].to_list(),
+                        n_jobs=-1,
                         **fs_params
                     )
 
@@ -141,8 +160,21 @@ def main(args):
                 epsilon = loss_threshold(n_classes, metric=conf.algos.metric)
             other = {'perf': {'epsilon': epsilon}}
 
-            model = integrator.run_isa(rootdir=rootdir_path, metadata=df_metadata, settings=other,
-                                       rotation_adjust=conf.isa.adjust_rotation, save_output=False)
+            logger.info("Adding gaussian noise to the metadata for numerical stability.")
+            df_features = df_metadata.filter(regex='^feature_')
+            # df_metadata[df_features.columns] += np.random.rand(*df_features.shape) * 1e-3
+            df_metadata[df_features.columns] += np.random.normal(0, 1e-3, size=df_features.shape)
+
+            # TODO: fix warnings in pyispace (issue #3)
+            with warnings.catch_warnings():
+                warnings.simplefilter("ignore")
+                model = integrator.run_isa(
+                    rootdir=rootdir_path,
+                    metadata=df_metadata,
+                    settings=other,
+                    rotation_adjust=conf.isa.adjust_rotation,
+                    save_output=False
+                )
 
             threshold = conf.isa.ih_threshold
             pi = conf.isa.ih_purity
@@ -152,8 +184,12 @@ def main(args):
             ih_fp = trace_build_wrapper(model.pilot.Z, Ybin, pi)
 
             # Calculate IH summary
-            ih_summary = make_summary(space=model.trace.space, good=[ih_fp], best=[_empty_footprint()],
-                                      algolabels=['instance_hardness'])
+            ih_summary = make_summary(
+                space=model.trace.space,
+                good=[ih_fp],
+                best=[_empty_footprint()],
+                algolabels=['instance_hardness']
+            )
             model.trace.summary = model.trace.summary.append(ih_summary)
 
             # Save footprints and models
