@@ -127,18 +127,18 @@ class ClassificationMeasures(BaseMeasures):
 
         # Decision Tree Classifier
         dtc = tree.DecisionTreeClassifier(min_samples_split=2, criterion='gini', random_state=seed)
-        self.dtc = dtc.fit(self.X, self.y)
+        self.dtc = dtc.fit(self.X.values, self.y.values)
 
         # Decision Tree Classifier Pruned
         if ccp_alpha is None:
             parameters = {'ccp_alpha': np.linspace(0.001, 0.1, num=100)}
             dtc = tree.DecisionTreeClassifier(criterion='gini', random_state=seed)
             clf = GridSearchCV(dtc, parameters, n_jobs=-1)
-            clf = clf.fit(self.X, self.y)
+            clf = clf.fit(self.X.values, self.y.values)
             ccp_alpha = clf.best_params_['ccp_alpha']
 
         self.dtc_pruned = tree.DecisionTreeClassifier(criterion='gini', ccp_alpha=ccp_alpha, random_state=seed)
-        self.dtc_pruned = self.dtc_pruned.fit(self.X, self.y)
+        self.dtc_pruned = self.dtc_pruned.fit(self.X.values, self.y.values)
 
         # Naive Bayes classifier
         n_c = self.y.nunique()
@@ -185,7 +185,7 @@ class ClassificationMeasures(BaseMeasures):
     def disjunct_class_percentage(self):
         data = self.data.copy()
 
-        data['leaf_id'] = self.dtc_pruned.apply(self.X)
+        data['leaf_id'] = self.dtc_pruned.apply(self.X.values)
         dcp = []
         for index, row in data.iterrows():
             df_leaf = data[data['leaf_id'] == row['leaf_id']]
