@@ -48,8 +48,10 @@ class FSConfig:
     max_n_features: int = 10
     method: str = 'NCA'
     parameters: dict = field(default_factory=dict)
-    variance_filter: bool = False
-    variance_threshold: float = 0
+    var_filter: bool = True
+    var_threshold: float = 0
+    corr_filter: bool = True
+    corr_threshold: float = 0.95
 
 
 @dataclass(frozen=True)
@@ -115,8 +117,8 @@ def from_old_format(d_old: dict):
         max_n_features=d_old.get('max_n_features'),
         method='IT',
         parameters=dict(criteria=d_old.get('method')),
-        variance_filter=d_old.get('var_filter'),
-        variance_threshold=d_old.get('var_threshold')
+        var_filter=d_old.get('var_filter'),
+        var_threshold=d_old.get('var_threshold')
     )
 
     hpo = HPOConfig(
